==> clean_directories-1.0.2.tar.gz: clean_directories-1.0.2/setup.py <==
"""An interface for the Slack web API

https://github.com/Shir0kamii/slack-client
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

import clean_directories

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='clean_directories',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=clean_directories.__version__,

    description='A script to clean your directories',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/Shir0kamii/clean',

    # Author details
    author='shir0kamii',
    author_email='Shir0kamii@prologin.org',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],

    # What does your project relate to?
    keywords='script clean directories',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=['clean_directories'],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['clize'],

    entry_points = {
        'console_scripts': [
            'clean = bin.clean:main',
            'cleaner = bin.cleaner:main'
        ]
    }
)

==> clean_directories-1.0.3.tar.gz: clean_directories-1.0.3/setup.py <==
"""An interface for the Slack web API

https://github.com/Shir0kamii/slack-client
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

import clean_directories

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='clean_directories',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=clean_directories.__version__,

    description='A script to clean your directories',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/Shir0kamii/clean',

    # Author details
    author='shir0kamii',
    author_email='Shir0kamii@prologin.org',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],

    # What does your project relate to?
    keywords='script clean directories',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=['clean_directories', 'bin'],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['clize'],

    entry_points = {
        'console_scripts': [
            'clean = bin.clean:main',
            'cleaner = bin.cleaner:main'
        ]
    }
)
